Mirror of the gdb-patches mailing list
 help / color / mirror / Atom feed
From: "Kei Sakamoto" <sakamoto.kei@renesas.com>
To: <gdb-patches@sources.redhat.com>
Subject: [commit] Replace "Hitachi" and "Mitsubishi" with "Renesas"
Date: Fri, 10 Oct 2003 07:23:00 -0000	[thread overview]
Message-ID: <01e401c38eff$57aa9e70$5169910a@KEI> (raw)

[-- Attachment #1: Type: text/plain, Size: 1401 bytes --]

Hello,

While I was writing a documentation for m32r new remote target,
I found that there were a lot of "Hitachi" and "Mitsubishi" in
source files and documentations.

Since they are now Renesas Technology, I replaced them with
"Renesas."

I've committed this as obvious.

Kei Sakamoto
Renesas Technology Corp.

===

ChangeLog:

2003-10-10  Kei Sakamoto  <sakamoto.kei@renesas.com>

        * NEWS: Replace "Hitachi" and "Mitsubishi" with "Renesas".
        * README: Ditto.
        * d10v-tdep.c: Ditto.
        * h8300-tdep.c: Ditto.
        * remote-e7000.c: Ditto.
        * remote-hms.c: Ditto.
        * ser-e7kpc.c: Ditto.
        * sh-stub.c: Ditto.
        * sh-tdep.c: Ditto.
        * sh-tdep.h: Ditto.
        * sh3-rom.c: Ditto.
        * sh64-tdep.c: Ditto.
        * top.c: Ditto.
        * wince.c: Ditto.
        * config/d10v/d10v.mt: Ditto.
        * config/sh/embed.mt: Ditto.
        * config/sh/linux.mt: Ditto.
        * config/sh/tm-linux.h: Ditto.
        * config/sh/tm-sh.h: Ditto.
        * config/sh/wince.mt: Ditto.

doc/ChangeLog:

2003-10-10  Kei Sakamoto  <sakamoto.kei@renesas.com>

        * gdb.texinfo: Replace "Hitachi" and "Mitsubishi" with "Renesas".
        * gdbint.texinfo: Ditto.

testsuite/ChangeLog:

2003-10-10  Kei Sakamoto  <sakamoto.kei@renesas.com>

        * config/hmsirom.exp: Replace "Hitachi" with "Renesas".
        * gdb.disasm/sh3.s: Ditto.

[-- Attachment #2: diffs --]
[-- Type: application/octet-stream, Size: 27644 bytes --]

Index: NEWS
===================================================================
RCS file: /cvs/src/src/gdb/NEWS,v
retrieving revision 1.123
diff -u -r1.123 NEWS
--- NEWS	6 Oct 2003 19:47:21 -0000	1.123
+++ NEWS	10 Oct 2003 06:52:55 -0000
@@ -141,7 +141,7 @@
 * Multi-arched targets.
 
 HP/PA HPUX11                                    hppa*-*-hpux*
-Mitsubishi M32R/D w/simulator			m32r-*-elf*
+Renesas M32R/D w/simulator			m32r-*-elf*
 
 * OBSOLETE configurations and files
 
Index: README
===================================================================
RCS file: /cvs/src/src/gdb/README,v
retrieving revision 1.28
diff -u -r1.28 README
--- README	23 Jun 2003 03:28:13 -0000	1.28
+++ README	10 Oct 2003 06:52:55 -0000
@@ -462,9 +462,9 @@
    There are a number of remote interfaces for talking to existing ROM
 monitors and other hardware:
 
-	remote-e7000.c	 Hitachi E7000 ICE
+	remote-e7000.c	 Renesas E7000 ICE
 	remote-est.c	 EST emulator
-	remote-hms.c	 Hitachi Micro Systems H8/300 monitor
+	remote-hms.c	 Renesas Micro Systems H8/300 monitor
 	remote-mips.c	 MIPS remote debugging protocol
 	remote-rdi.c	 ARM with Angel monitor
 	remote-rdp.c	 ARM with Demon monitor
Index: d10v-tdep.c
===================================================================
RCS file: /cvs/src/src/gdb/d10v-tdep.c,v
retrieving revision 1.133
diff -u -r1.133 d10v-tdep.c
--- d10v-tdep.c	10 Oct 2003 00:25:42 -0000	1.133
+++ d10v-tdep.c	10 Oct 2003 06:52:55 -0000
@@ -1,4 +1,4 @@
-/* Target-dependent code for Mitsubishi D10V, for GDB.
+/* Target-dependent code for Renesas D10V, for GDB.
 
    Copyright 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2003 Free Software
    Foundation, Inc.
Index: h8300-tdep.c
===================================================================
RCS file: /cvs/src/src/gdb/h8300-tdep.c,v
retrieving revision 1.84
diff -u -r1.84 h8300-tdep.c
--- h8300-tdep.c	28 Sep 2003 22:32:19 -0000	1.84
+++ h8300-tdep.c	10 Oct 2003 06:52:55 -0000
@@ -1,4 +1,4 @@
-/* Target-machine dependent code for Hitachi H8/300, for GDB.
+/* Target-machine dependent code for Renesas H8/300, for GDB.
 
    Copyright 1988, 1990, 1991, 1992, 1993, 1994, 1995, 1996, 1998,
    1999, 2000, 2001, 2002, 2003 Free Software Foundation, Inc.
Index: ser-e7kpc.c
===================================================================
RCS file: /cvs/src/src/gdb/ser-e7kpc.c,v
retrieving revision 1.9
diff -u -r1.9 ser-e7kpc.c
--- ser-e7kpc.c	11 Jun 2003 13:16:29 -0000	1.9
+++ ser-e7kpc.c	10 Oct 2003 06:52:55 -0000
@@ -1,4 +1,4 @@
-/* Remote serial interface using Hitachi E7000 PC ISA card in a PC
+/* Remote serial interface using Renesas E7000 PC ISA card in a PC
    Copyright 1994, 1996, 1997, 1998, 1999, 2000
    Free Software Foundation, Inc.
 
Index: sh-tdep.h
===================================================================
RCS file: /cvs/src/src/gdb/sh-tdep.h,v
retrieving revision 1.6
diff -u -r1.6 sh-tdep.h
--- sh-tdep.h	16 Sep 2003 15:56:03 -0000	1.6
+++ sh-tdep.h	10 Oct 2003 06:52:56 -0000
@@ -1,4 +1,4 @@
-/* Target-specific definition for a Hitachi Super-H.
+/* Target-specific definition for a Renesas Super-H.
    Copyright 1993, 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2003
    Free Software Foundation, Inc.
 
Index: top.c
===================================================================
RCS file: /cvs/src/src/gdb/top.c,v
retrieving revision 1.80
diff -u -r1.80 top.c
--- top.c	6 Oct 2003 22:41:17 -0000	1.80
+++ top.c	10 Oct 2003 06:52:56 -0000
@@ -147,7 +147,7 @@
    In mid-1996, remote_timeout was moved from remote.c to top.c and 
    it began being used in other remote-* targets.  It appears that the
    default was changed to 20 seconds at that time, perhaps because the
-   Hitachi E7000 ICE didn't always respond in a timely manner.
+   Renesas E7000 ICE didn't always respond in a timely manner.
 
    But if 5 seconds is a long time to sit and wait for retransmissions,
    20 seconds is far worse.  This demonstrates the difficulty of using 
Index: wince.c
===================================================================
RCS file: /cvs/src/src/gdb/wince.c,v
retrieving revision 1.24
diff -u -r1.24 wince.c
--- wince.c	21 Sep 2003 01:26:46 -0000	1.24
+++ wince.c	10 Oct 2003 06:52:56 -0000
@@ -833,7 +833,7 @@
   return;
 }
 #elif SHx
-/* Hitachi SH architecture instruction encoding masks */
+/* Renesas SH architecture instruction encoding masks */
 
 #define COND_BR_MASK   0xff00
 #define UCOND_DBR_MASK 0xe000
@@ -844,7 +844,7 @@
 #define UCOND_DISP     0x0fff
 #define UCOND_REG      0x0f00
 
-/* Hitachi SH instruction opcodes */
+/* Renesas SH instruction opcodes */
 
 #define BF_INSTR       0x8b00
 #define BT_INSTR       0x8900
Index: config/d10v/d10v.mt
===================================================================
RCS file: /cvs/src/src/gdb/config/d10v/d10v.mt,v
retrieving revision 1.2
diff -u -r1.2 d10v.mt
--- config/d10v/d10v.mt	11 Jul 2001 17:58:15 -0000	1.2
+++ config/d10v/d10v.mt	10 Oct 2003 06:52:56 -0000
@@ -1,4 +1,4 @@
-# Target: Mitsubishi D10V processor
+# Target: Renesas D10V processor
 TDEPFILES= d10v-tdep.o
 SIM_OBS= remote-sim.o
 SIM= ../sim/d10v/libsim.a
Index: config/sh/embed.mt
===================================================================
RCS file: /cvs/src/src/gdb/config/sh/embed.mt,v
retrieving revision 1.2
diff -u -r1.2 embed.mt
--- config/sh/embed.mt	8 Sep 2003 11:26:21 -0000	1.2
+++ config/sh/embed.mt	10 Oct 2003 06:52:56 -0000
@@ -1,4 +1,4 @@
-# Target: Embedded Hitachi Super-H with ICE and simulator
+# Target: Embedded Renesas Super-H with ICE and simulator
 TDEPFILES= sh-tdep.o sh64-tdep.o monitor.o sh3-rom.o remote-e7000.o ser-e7kpc.o dsrec.o 
 TM_FILE= tm-sh.h
 
Index: config/sh/linux.mt
===================================================================
RCS file: /cvs/src/src/gdb/config/sh/linux.mt,v
retrieving revision 1.5
diff -u -r1.5 linux.mt
--- config/sh/linux.mt	8 Sep 2003 11:26:21 -0000	1.5
+++ config/sh/linux.mt	10 Oct 2003 06:52:56 -0000
@@ -1,4 +1,4 @@
-# Target: Hitachi Super-H running GNU/Linux
+# Target: Renesas Super-H running GNU/Linux
 TDEPFILES= sh-tdep.o sh64-tdep.o monitor.o sh3-rom.o remote-e7000.o ser-e7kpc.o dsrec.o solib.o solib-svr4.o solib-legacy.o
 TM_FILE= tm-linux.h
 
Index: config/sh/tm-linux.h
===================================================================
RCS file: /cvs/src/src/gdb/config/sh/tm-linux.h,v
retrieving revision 1.4
diff -u -r1.4 tm-linux.h
--- config/sh/tm-linux.h	5 Jun 2002 19:18:28 -0000	1.4
+++ config/sh/tm-linux.h	10 Oct 2003 06:52:56 -0000
@@ -1,4 +1,4 @@
-/* Target-specific definitions for GNU/Linux running on a Hitachi
+/* Target-specific definitions for GNU/Linux running on a Renesas
    Super-H.
 
    Copyright 2000, 2002 Free Software Foundation, Inc.
Index: config/sh/tm-sh.h
===================================================================
RCS file: /cvs/src/src/gdb/config/sh/tm-sh.h,v
retrieving revision 1.21
diff -u -r1.21 tm-sh.h
--- config/sh/tm-sh.h	8 Sep 2003 11:26:21 -0000	1.21
+++ config/sh/tm-sh.h	10 Oct 2003 06:52:56 -0000
@@ -1,4 +1,4 @@
-/* Target-specific definition for a Hitachi Super-H.
+/* Target-specific definition for a Renesas Super-H.
    Copyright 1993, 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002
    Free Software Foundation, Inc.
 
Index: config/sh/wince.mt
===================================================================
RCS file: /cvs/src/src/gdb/config/sh/wince.mt,v
retrieving revision 1.3
diff -u -r1.3 wince.mt
--- config/sh/wince.mt	8 Sep 2003 11:26:21 -0000	1.3
+++ config/sh/wince.mt	10 Oct 2003 06:52:56 -0000
@@ -1,4 +1,4 @@
-# Target: Hitachi Super-H running on Windows CE
+# Target: Renesas Super-H running on Windows CE
 TDEPFILES= sh-tdep.o sh64-tdep.o wince.o
 TM_FILE= tm-wince.h
 MT_CFLAGS=-DSHx -U_X86_ -U_M_IX86 -U__i386__ -U__i486__ -U__i586__ -U__i686__ -DUNICODE -D_WIN32_WCE -DWINCE_STUB='"${target_alias}-stub.exe"'
Index: doc/gdb.texinfo
===================================================================
RCS file: /cvs/src/src/gdb/doc/gdb.texinfo,v
retrieving revision 1.177
diff -u -r1.177 gdb.texinfo
--- doc/gdb.texinfo	10 Oct 2003 02:13:07 -0000	1.177
+++ doc/gdb.texinfo	10 Oct 2003 06:52:59 -0000
@@ -418,12 +418,12 @@
 He also enhanced the command-completion support to cover C@t{++} overloaded
 symbols.
 
-Hitachi America, Ltd. sponsored the support for H8/300, H8/500, and
+Renesas America, Ltd. sponsored the support for H8/300, H8/500, and
 Super-H processors.
 
 NEC sponsored the support for the v850, Vr4xxx, and Vr5xxx processors.
 
-Mitsubishi sponsored the support for D10V, D30V, and M32R/D processors.
+Renesas sponsored the support for D10V, D30V, and M32R/D processors.
 
 Toshiba sponsored the support for the TX39 Mips processor.
 
@@ -10481,7 +10481,7 @@
 @cindex choosing target byte order
 @cindex target byte order
 
-Some types of processors, such as the MIPS, PowerPC, and Hitachi SH,
+Some types of processors, such as the MIPS, PowerPC, and Renesas SH,
 offer the ability to run either big-endian or little-endian byte
 orders.  Usually the executable or symbol will include a bit to
 designate the endian-ness, and you will not need to worry about
@@ -10928,9 +10928,9 @@
 
 @item sh-stub.c
 @cindex @file{sh-stub.c}
-@cindex Hitachi
+@cindex Renesas
 @cindex SH
-For Hitachi SH architectures.
+For Renesas SH architectures.
 
 @item sparc-stub.c
 @cindex @file{sparc-stub.c}
@@ -11782,15 +11782,15 @@
 
 @menu
 * ARM::                         ARM
-* H8/300::                      Hitachi H8/300
-* H8/500::                      Hitachi H8/500
-* M32R/D::                      Mitsubishi M32R/D
+* H8/300::                      Renesas H8/300
+* H8/500::                      Renesas H8/500
+* M32R/D::                      Renesas M32R/D
 * M68K::                        Motorola M68K
 * MIPS Embedded::               MIPS Embedded
 * OpenRISC 1000::               OpenRisc 1000
 * PA::                          HP PA Embedded
 * PowerPC:                      PowerPC
-* SH::                          Hitachi SH
+* SH::                          Renesas SH
 * Sparclet::                    Tsqware Sparclet
 * Sparclite::                   Fujitsu Sparclite
 * ST2000::                      Tandem ST2000
@@ -11815,50 +11815,50 @@
 @end table
 
 @node H8/300
-@subsection Hitachi H8/300
+@subsection Renesas H8/300
 
 @table @code
 
 @kindex target hms@r{, with H8/300}
 @item target hms @var{dev}
-A Hitachi SH, H8/300, or H8/500 board, attached via serial line to your host.
+A Renesas SH, H8/300, or H8/500 board, attached via serial line to your host.
 Use special commands @code{device} and @code{speed} to control the serial
 line and the communications speed used.
 
 @kindex target e7000@r{, with H8/300}
 @item target e7000 @var{dev}
-E7000 emulator for Hitachi H8 and SH.
+E7000 emulator for Renesas H8 and SH.
 
 @kindex target sh3@r{, with H8/300}
 @kindex target sh3e@r{, with H8/300}
 @item target sh3 @var{dev}
 @itemx target sh3e @var{dev}
-Hitachi SH-3 and SH-3E target systems.
+Renesas SH-3 and SH-3E target systems.
 
 @end table
 
 @cindex download to H8/300 or H8/500
 @cindex H8/300 or H8/500 download
-@cindex download to Hitachi SH
-@cindex Hitachi SH download
-When you select remote debugging to a Hitachi SH, H8/300, or H8/500
-board, the @code{load} command downloads your program to the Hitachi
+@cindex download to Renesas SH
+@cindex Renesas SH download
+When you select remote debugging to a Renesas SH, H8/300, or H8/500
+board, the @code{load} command downloads your program to the Renesas
 board and also opens it as the current executable target for
 @value{GDBN} on your host (like the @code{file} command).
 
 @value{GDBN} needs to know these things to talk to your
-Hitachi SH, H8/300, or H8/500:
+Renesas SH, H8/300, or H8/500:
 
 @enumerate
 @item
 that you want to use @samp{target hms}, the remote debugging interface
-for Hitachi microprocessors, or @samp{target e7000}, the in-circuit
-emulator for the Hitachi SH and the Hitachi 300H.  (@samp{target hms} is
-the default when @value{GDBN} is configured specifically for the Hitachi SH,
+for Renesas microprocessors, or @samp{target e7000}, the in-circuit
+emulator for the Renesas SH and the Renesas 300H.  (@samp{target hms} is
+the default when @value{GDBN} is configured specifically for the Renesas SH,
 H8/300, or H8/500.)
 
 @item
-what serial device connects your host to your Hitachi board (the first
+what serial device connects your host to your Renesas board (the first
 serial device available on your host is the default).
 
 @item
@@ -11866,24 +11866,24 @@
 @end enumerate
 
 @menu
-* Hitachi Boards::      Connecting to Hitachi boards.
-* Hitachi ICE::         Using the E7000 In-Circuit Emulator.
-* Hitachi Special::     Special @value{GDBN} commands for Hitachi micros.
+* Renesas Boards::      Connecting to Renesas boards.
+* Renesas ICE::         Using the E7000 In-Circuit Emulator.
+* Renesas Special::     Special @value{GDBN} commands for Renesas micros.
 @end menu
 
-@node Hitachi Boards
-@subsubsection Connecting to Hitachi boards
+@node Renesas Boards
+@subsubsection Connecting to Renesas boards
 
 @c only for Unix hosts
 @kindex device
-@cindex serial device, Hitachi micros
+@cindex serial device, Renesas micros
 Use the special @code{@value{GDBN}} command @samp{device @var{port}} if you
 need to explicitly set the serial device.  The default @var{port} is the
 first available port on your host.  This is only necessary on Unix
 hosts, where it is typically something like @file{/dev/ttya}.
 
 @kindex speed
-@cindex serial line speed, Hitachi micros
+@cindex serial line speed, Renesas micros
 @code{@value{GDBN}} has another special command to set the communications
 speed: @samp{speed @var{bps}}.  This command also is only used from Unix
 hosts; on DOS hosts, set the line speed as usual from outside @value{GDBN} with
@@ -11891,7 +11891,7 @@
 @w{@kbd{mode com2:9600,n,8,1,p}} for a 9600@dmn{bps} connection).
 
 The @samp{device} and @samp{speed} commands are available only when you
-use a Unix host to debug your Hitachi microprocessor programs.  If you
+use a Unix host to debug your Renesas microprocessor programs.  If you
 use a DOS host,
 @value{GDBN} depends on an auxiliary terminate-and-stay-resident program
 called @code{asynctsr} to communicate with the development board
@@ -11901,7 +11901,7 @@
 The following sample session illustrates the steps needed to start a
 program under @value{GDBN} control on an H8/300.  The example uses a
 sample H8/300 program called @file{t.x}.  The procedure is the same for
-the Hitachi SH and the H8/500.
+the Renesas SH and the H8/500.
 
 First hook up your development board.  In this example, we use a
 board attached to serial port @code{COM2}; if you use a different serial
@@ -11934,7 +11934,7 @@
 the name of your program as the argument.  @code{@value{GDBN}} prompts
 you, as usual, with the prompt @samp{(@value{GDBP})}.  Use two special
 commands to begin your debugging session: @samp{target hms} to specify
-cross-debugging to the Hitachi board, and the @code{load} command to
+cross-debugging to the Renesas board, and the @code{load} command to
 download your program to the board.  @code{load} displays the names of
 the program's sections, and a @samp{*} for each 2K of data downloaded.
 (If you want to refresh @value{GDBN} data on symbols or on the
@@ -11984,12 +11984,12 @@
 In either case, @value{GDBN} sees the effect of a @sc{reset} on the
 development board as a ``normal exit'' of your program.
 
-@node Hitachi ICE
+@node Renesas ICE
 @subsubsection Using the E7000 in-circuit emulator
 
-@kindex target e7000@r{, with Hitachi ICE}
+@kindex target e7000@r{, with Renesas ICE}
 You can use the E7000 in-circuit emulator to develop code for either the
-Hitachi SH or the H8/300H.  Use one of these forms of the @samp{target
+Renesas SH or the H8/300H.  Use one of these forms of the @samp{target
 e7000} command to connect @value{GDBN} to your E7000:
 
 @table @code
@@ -12004,8 +12004,8 @@
 specify its hostname; @value{GDBN} uses @code{telnet} to connect.
 @end table
 
-@node Hitachi Special
-@subsubsection Special @value{GDBN} commands for Hitachi micros
+@node Renesas Special
+@subsubsection Special @value{GDBN} commands for Renesas micros
 
 Some @value{GDBN} commands are available only for the H8/300:
 
@@ -12038,13 +12038,13 @@
 @end table
 
 @node M32R/D
-@subsection Mitsubishi M32R/D
+@subsection Renesas M32R/D
 
 @table @code
 
 @kindex target m32r
 @item target m32r @var{dev}
-Mitsubishi M32R/D ROM monitor.
+Renesas M32R/D ROM monitor.
 
 @end table
 
@@ -12391,25 +12391,25 @@
 @end table
 
 @node SH
-@subsection Hitachi SH
+@subsection Renesas SH
 
 @table @code
 
-@kindex target hms@r{, with Hitachi SH}
+@kindex target hms@r{, with Renesas SH}
 @item target hms @var{dev}
-A Hitachi SH board attached via serial line to your host.  Use special
+A Renesas SH board attached via serial line to your host.  Use special
 commands @code{device} and @code{speed} to control the serial line and
 the communications speed used.
 
-@kindex target e7000@r{, with Hitachi SH}
+@kindex target e7000@r{, with Renesas SH}
 @item target e7000 @var{dev}
-E7000 emulator for Hitachi SH.
+E7000 emulator for Renesas SH.
 
 @kindex target sh3@r{, with SH}
 @kindex target sh3e@r{, with SH}
 @item target sh3 @var{dev}
 @item target sh3e @var{dev}
-Hitachi SH-3 and SH-3E target systems.
+Renesas SH-3 and SH-3E target systems.
 
 @end table
 
Index: doc/gdbint.texinfo
===================================================================
RCS file: /cvs/src/src/gdb/doc/gdbint.texinfo,v
retrieving revision 1.173
diff -u -r1.173 gdbint.texinfo
--- doc/gdbint.texinfo	3 Oct 2003 20:56:43 -0000	1.173
+++ doc/gdbint.texinfo	10 Oct 2003 06:53:00 -0000
@@ -2505,7 +2505,7 @@
 address space, so they may choose a pointer representation that breaks this
 identity, and allows a larger code address space.
 
-For example, the Mitsubishi D10V is a 16-bit VLIW processor whose
+For example, the Renesas D10V is a 16-bit VLIW processor whose
 instructions are 32 bits long@footnote{Some D10V instructions are
 actually pairs of 16-bit sub-instructions.  However, since you can't
 jump into the middle of such a pair, code addresses can only refer to
Index: testsuite/config/hmsirom.exp
===================================================================
RCS file: /cvs/src/src/gdb/testsuite/config/hmsirom.exp,v
retrieving revision 1.2
diff -u -r1.2 hmsirom.exp
--- testsuite/config/hmsirom.exp	6 Mar 2001 08:21:48 -0000	1.2
+++ testsuite/config/hmsirom.exp	10 Oct 2003 06:53:00 -0000
@@ -17,6 +17,6 @@
 # Please email any bugs, comments, and/or additions to this file to:
 # bug-gdb@prep.ai.mit.edu
 
-# Support for testing against a Hitachi SH3 target rom
+# Support for testing against a Renesas SH3 target rom
 
 load_lib ../config/monitor.exp
Index: testsuite/gdb.disasm/sh3.s
===================================================================
RCS file: /cvs/src/src/gdb/testsuite/gdb.disasm/sh3.s,v
retrieving revision 1.1.1.1
diff -u -r1.1.1.1 sh3.s
--- testsuite/gdb.disasm/sh3.s	16 Apr 1999 01:34:33 -0000	1.1.1.1
+++ testsuite/gdb.disasm/sh3.s	10 Oct 2003 06:53:00 -0000
@@ -1,7 +1,7 @@
 	.file	"test.c"
 	.data
 
-! Hitachi SH cc1 (cygnus-2.7.1-950728) arguments: -O -fpeephole
+! Renesas SH cc1 (cygnus-2.7.1-950728) arguments: -O -fpeephole
 ! -ffunction-cse -freg-struct-return -fdelayed-branch -fcommon -fgnu-linker
 
 gcc2_compiled.:

             reply	other threads:[~2003-10-10  7:23 UTC|newest]

Thread overview: 3+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2003-10-10  7:23 Kei Sakamoto [this message]
2003-10-10 14:34 ` Andrew Cagney
2003-10-14  4:30   ` Kei Sakamoto

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to='01e401c38eff$57aa9e70$5169910a@KEI' \
    --to=sakamoto.kei@renesas.com \
    --cc=gdb-patches@sources.redhat.com \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox
Index: remote-e7000.c
===================================================================
RCS file: /cvs/src/src/gdb/remote-e7000.c,v
retrieving revision 1.37
diff -u -r1.37 remote-e7000.c
--- remote-e7000.c	2 Oct 2003 20:28:30 -0000	1.37
+++ remote-e7000.c	10 Oct 2003 06:52:55 -0000
@@ -1,4 +1,4 @@
 /* Remote debugging interface for Hitachi E7000 ICE, for GDB
 
    Copyright 1993, 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001,
    2002, 2003 Free Software Foundation, Inc.
@@ -24,8 +24,8 @@
    Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.  */
 
-/* The E7000 is an in-circuit emulator for the Hitachi H8/300-H and
-   Hitachi-SH processor.  It has serial port and a lan port.  
+/* The E7000 is an in-circuit emulator for the Renesas H8/300-H and
+   Renesas-SH processor.  It has serial port and a lan port.  
 
    The monitor command set makes it difficult to load large ammounts of
    data over the lan without using ftp - so try not to issue load
@@ -2131,8 +2131,8 @@
 init_e7000_ops (void)
 {
   e7000_ops.to_shortname = "e7000";
-  e7000_ops.to_longname = "Remote Hitachi e7000 target";
-  e7000_ops.to_doc = "Use a remote Hitachi e7000 ICE connected by a serial line;\n\
+  e7000_ops.to_longname = "Remote Renesas e7000 target";
+  e7000_ops.to_doc = "Use a remote Renesas e7000 ICE connected by a serial line;\n\
 or a network connection.\n\
 Arguments are the name of the device for the serial line,\n\
 the speed to connect at in bits per second.\n\
@@ -1,4 +1,4 @@
-/* Remote debugging interface for Hitachi E7000 ICE, for GDB
+/* Remote debugging interface for Renesas E7000 ICE, for GDB
 
    Copyright 1993, 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001,
Index: remote-hms.c
===================================================================
RCS file: /cvs/src/src/gdb/remote-hms.c,v
retrieving revision 1.7
diff -u -r1.7 remote-hms.c
--- remote-hms.c	11 Jun 2003 13:16:28 -0000	1.7
+++ remote-hms.c	10 Oct 2003 06:52:55 -0000
@@ -1,4 +1,4 @@
 /* Remote debugging interface for Hitachi HMS Monitor Version 1.0
    Copyright 1995, 1996, 1998, 1999, 2000, 2001
    Free Software Foundation, Inc.
    Contributed by Cygnus Support.  Written by Steve Chamberlain
@@ -149,7 +149,7 @@
   init_monitor_ops (&hms_ops);
 
   hms_ops.to_shortname = "hms";
-  hms_ops.to_longname = "Hitachi Microsystems H8/300 debug monitor";
+  hms_ops.to_longname = "Renesas Microsystems H8/300 debug monitor";
   hms_ops.to_doc = "Debug via the HMS monitor.\n\
 Specify the serial device it is connected to (e.g. /dev/ttya).";
   hms_ops.to_open = hms_open;
@@ -1,4 +1,4 @@
-/* Remote debugging interface for Hitachi HMS Monitor Version 1.0
+/* Remote debugging interface for Renesas HMS Monitor Version 1.0
    Copyright 1995, 1996, 1998, 1999, 2000, 2001
    Free Software Foundation, Inc.
Index: sh-stub.c
===================================================================
RCS file: /cvs/src/src/gdb/sh-stub.c,v
retrieving revision 1.3
diff -u -r1.3 sh-stub.c
--- sh-stub.c	16 Sep 2003 18:56:35 -0000	1.3
+++ sh-stub.c	10 Oct 2003 06:52:55 -0000
@@ -1,4 +1,4 @@
 /* sh-stub.c -- debugging stub for the Hitachi-SH.
 
  NOTE!! This code has to be compiled with optimization, otherwise the 
  function inlining which generates the exception handlers won't work.
@@ -147,7 +147,7 @@
 #include <string.h>
 #include <setjmp.h>
 
 /* Hitachi SH architecture instruction encoding masks */
 
 #define COND_BR_MASK   0xff00
 #define UCOND_DBR_MASK 0xe000
@@ -158,7 +158,7 @@
 #define UCOND_DISP     0x0fff
 #define UCOND_REG      0x0f00
 
 /* Hitachi SH instruction opcodes */
 
 #define BF_INSTR       0x8b00
 #define BT_INSTR       0x8900
@@ -171,7 +171,7 @@
 #define TRAPA_INSTR    0xc300
 #define SSTEP_INSTR    0xc3ff
 
 /* Hitachi SH processor register masks */
 
 #define T_BIT_MASK     0x0001
 
@@ -824,7 +824,7 @@
 
 /* Note:
 
-   The Hitachi SH family uses two exception architectures:
+   The Renesas SH family uses two exception architectures:
 
    SH1 & SH2:
 
@@ -1,4 +1,4 @@
-/* sh-stub.c -- debugging stub for the Hitachi-SH.
+/* sh-stub.c -- debugging stub for the Renesas-SH.
 
  NOTE!! This code has to be compiled with optimization, otherwise the 
@@ -147,7 +147,7 @@
 #include <setjmp.h>
 
-/* Hitachi SH architecture instruction encoding masks */
+/* Renesas SH architecture instruction encoding masks */
 
 #define COND_BR_MASK   0xff00
@@ -158,7 +158,7 @@
 #define UCOND_REG      0x0f00
 
-/* Hitachi SH instruction opcodes */
+/* Renesas SH instruction opcodes */
 
 #define BF_INSTR       0x8b00
@@ -171,7 +171,7 @@
 #define SSTEP_INSTR    0xc3ff
 
-/* Hitachi SH processor register masks */
+/* Renesas SH processor register masks */
 
 #define T_BIT_MASK     0x0001
Index: sh-tdep.c
===================================================================
RCS file: /cvs/src/src/gdb/sh-tdep.c,v
retrieving revision 1.147
diff -u -r1.147 sh-tdep.c
--- sh-tdep.c	10 Oct 2003 03:14:08 -0000	1.147
+++ sh-tdep.c	10 Oct 2003 06:52:56 -0000
@@ -1,4 +1,4 @@
 /* Target-dependent code for Hitachi Super-H, for GDB.
    Copyright 1993, 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2003
    Free Software Foundation, Inc.
 
@@ -614,7 +614,7 @@
 /* Function: push_dummy_call (formerly push_arguments)
    Setup the function arguments for calling a function in the inferior.
 
-   On the Hitachi SH architecture, there are four registers (R4 to R7)
+   On the Renesas SH architecture, there are four registers (R4 to R7)
    which are dedicated for passing function arguments.  Up to the first
    four arguments (depending on size) may go into these registers.
    The rest go on the stack.
@@ -1,4 +1,4 @@
-/* Target-dependent code for Hitachi Super-H, for GDB.
+/* Target-dependent code for Renesas Super-H, for GDB.
    Copyright 1993, 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2003
    Free Software Foundation, Inc.
Index: sh3-rom.c
===================================================================
RCS file: /cvs/src/src/gdb/sh3-rom.c,v
retrieving revision 1.16
diff -u -r1.16 sh3-rom.c
--- sh3-rom.c	16 Sep 2003 15:56:03 -0000	1.16
+++ sh3-rom.c	10 Oct 2003 06:52:56 -0000
@@ -1,4 +1,4 @@
 /* Remote target glue for the Hitachi SH-3 ROM monitor.
    Copyright 1995, 1996, 1997, 1998, 1999, 2000, 2001
    Free Software Foundation, Inc.
 
@@ -365,11 +365,11 @@
   init_monitor_ops (&sh3_ops);
 
   sh3_ops.to_shortname = "sh3";
-  sh3_ops.to_longname = "Hitachi SH-3 rom monitor";
+  sh3_ops.to_longname = "Renesas SH-3 rom monitor";
 
   sh3_ops.to_doc =
   /* We can download through the parallel port too. */
-    "Debug on a Hitachi eval board running the SH-3E rom monitor.\n"
+    "Debug on a Renesas eval board running the SH-3E rom monitor.\n"
     "Specify the serial device it is connected to.\n"
     "If you want to use the parallel port to download to it, specify that\n"
     "as an additional second argument.";
@@ -384,11 +384,11 @@
   init_monitor_ops (&sh3e_ops);
 
   sh3e_ops.to_shortname = "sh3e";
-  sh3e_ops.to_longname = "Hitachi SH-3E rom monitor";
+  sh3e_ops.to_longname = "Renesas SH-3E rom monitor";
 
   sh3e_ops.to_doc =
   /* We can download through the parallel port too. */
-    "Debug on a Hitachi eval board running the SH-3E rom monitor.\n"
+    "Debug on a Renesas eval board running the SH-3E rom monitor.\n"
     "Specify the serial device it is connected to.\n"
     "If you want to use the parallel port to download to it, specify that\n"
     "as an additional second argument.";
@@ -1,4 +1,4 @@
-/* Remote target glue for the Hitachi SH-3 ROM monitor.
+/* Remote target glue for the Renesas SH-3 ROM monitor.
    Copyright 1995, 1996, 1997, 1998, 1999, 2000, 2001
    Free Software Foundation, Inc.
Index: sh64-tdep.c
===================================================================
RCS file: /cvs/src/src/gdb/sh64-tdep.c,v
retrieving revision 1.10
diff -u -r1.10 sh64-tdep.c
--- sh64-tdep.c	2 Oct 2003 20:28:30 -0000	1.10
+++ sh64-tdep.c	10 Oct 2003 06:52:56 -0000
@@ -1,4 +1,4 @@
 /* Target-dependent code for Hitachi Super-H, for GDB.
    Copyright 1993, 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2003
    Free Software Foundation, Inc.
 
@@ -1414,7 +1414,7 @@
 /* Function: push_arguments
    Setup the function arguments for calling a function in the inferior.
 
-   On the Hitachi SH architecture, there are four registers (R4 to R7)
+   On the Renesas SH architecture, there are four registers (R4 to R7)
    which are dedicated for passing function arguments.  Up to the first
    four arguments (depending on size) may go into these registers.
    The rest go on the stack.
@@ -1,4 +1,4 @@
-/* Target-dependent code for Hitachi Super-H, for GDB.
+/* Target-dependent code for Renesas Super-H, for GDB.
    Copyright 1993, 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2003
    Free Software Foundation, Inc.